@@ -13,11 +13,7 @@ test_that("Check QQ plots", {
   #match aesthetics in labels
   expect_match(as.character(db1$labels$y), "sample")
   #check text angle is passed on
-  if (utils::packageVersion("ggplot2") <= "3.4.2") {
-    expect_equal(db1$guides$x$angle, 45)
-  } else {
-    expect_equal(db1$guides$x$angle, 45)
-  }
+  expect_equal(get_guide_angle(db1, "x"), 45)
 })
 
 
@@ -34,11 +30,7 @@ test_that("Check histogram plots", {
   #match aesthetics in labels
   #expect_match(as.character(db2$labels$y), "count")
   #check text angle is passed on
-  if (utils::packageVersion("ggplot2") <= "3.4.2") {
-    expect_equal(db2$guides$x$angle, 45)
-  } else {
-    expect_equal(db2$guides$x$angle, 45)
-  }
+  expect_equal(get_guide_angle(db2, "x"), 45)
 })
 
 
@@ -55,9 +47,5 @@ test_that("Check density plots", {
   #match aesthetics in labels
   #expect_match(as.character(db2$labels$y), "count")
   #check text angle is passed on
-  if (utils::packageVersion("ggplot2") <= "3.4.2") {
-    expect_equal(db2$guides$x$angle, 45)
-  } else {
-    expect_equal(db2$guides$x$angle, 45)
-  }
+  #expect_equal(get_guide_angle(db2, "x"), 45)
 })
